# eric7.MicroPython.BluetoothDialogs.BluetoothController

Module implementing the Bluetooth related functionality.

### Global Attributes

None

### Classes

BluetoothController | Class implementing the Bluetooth related functionality.

### Functions

None

## BluetoothController

Class implementing the Bluetooth related functionality.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

BluetoothController | Constructor
__activateInterface | Private slot to activate the Bluetooth interface.
__deactivateInterface | Private slot to deactivate the Bluetooth interface.
__scan | Private slot to scan for Bluetooth devices.
__showBtStatus | Private slot to show the status and some parameters of the Bluetooth interface.
createMenu | Public method to create the Bluetooth submenu.

### Static Methods

None

#### BluetoothController (Constructor)

BluetoothController(microPython, parent=None)

Constructor

microPython (MicroPythonWidgep)
  reference to the MicroPython widget
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### BluetoothController.__activateInterface

__activateInterface()

Private slot to activate the Bluetooth interface.

#### BluetoothController.__deactivateInterface

__deactivateInterface()

Private slot to deactivate the Bluetooth interface.

#### BluetoothController.__scan

__scan()

Private slot to scan for Bluetooth devices.

#### BluetoothController.__showBtStatus

__showBtStatus()

Private slot to show the status and some parameters of the Bluetooth interface.

#### BluetoothController.createMenu

createMenu(menu)

Public method to create the Bluetooth submenu.

menu (QMenu)
  reference to the parent menu

Return:
  reference to the created menu

Return Type:
  QMenu

Up